// Generated by LiveScript 1.5.0
var ref$, cyan, green, red, blue, inquirer, fs, glob, yaml, Logger, templatesPath, merge, N, path, flatten, tmplconv, yamlCutter;
ref$ = require('chalk'), cyan = ref$.cyan, green = ref$.green, red = ref$.red, blue = ref$.blue;
inquirer = require('inquirer');
fs = require('fs');
glob = require('glob');
yaml = require('js-yaml');
ref$ = require('../../exosphere-shared'), Logger = ref$.Logger, templatesPath = ref$.templatesPath;
merge = require('merge');
N = require('nitroglycerin');
path = require('path');
flatten = require('prelude-ls').flatten;
tmplconv = require('tmplconv');
yamlCutter = require('yaml-cutter');
module.exports = function(){
  var ref$, data, questions, appConfig, e;
  if (process.argv[2] === "help") {
    return help();
  }
  console.log('We are about to add a new Exosphere service to the application!\n');
  ref$ = parseCommandLine(process.argv), data = ref$.data, questions = ref$.questions;
  try {
    appConfig = yaml.safeLoad(fs.readFileSync('application.yml', 'utf8'));
  } catch (e$) {
    e = e$;
    if (e.code === 'ENOENT') {
      console.log(red("Error: application.yml not found. Please run this command in the root directory of an Exosphere application."));
      process.exit();
    }
    throw e;
  }
  return inquirer.prompt(questions).then(function(answers){
    var srcPath, targetPath;
    data = merge(data, answers);
    checkForService({
      existingServices: getExistingServices(appConfig.services),
      serviceRole: data.serviceRole
    });
    srcPath = path.join(templatesPath, 'add-service', data.templateName);
    targetPath = path.join(process.cwd(), data.serviceType);
    data.appName = appConfig.name;
    return tmplconv.render(srcPath, targetPath, {
      data: data
    }).then(function(){
      var options;
      options = {
        file: 'application.yml',
        root: 'services.public',
        key: data.serviceRole,
        value: {
          location: "./" + data.serviceType
        }
      };
      return yamlCutter.insertHash(options, N(function(){
        return console.log(green("\ndone"));
      }));
    });
  });
};
function serviceRoles(){
  return fs.readdirSync(path.join(templatesPath, 'add-service'));
}
function help(){
  var helpMessage;
  helpMessage = "\nUsage: " + cyan('exo add') + " " + blue('[<entity-name>]') + "\n\nAdds a new service to the current application.\nThis command must be called in the root directory of the application.\n\noptions: " + blue('[<service-role>] [<service-type>] [<template>] [<model>] [<description>]');
  return console.log(helpMessage);
}
function checkForService(arg$){
  var serviceRole, existingServices;
  serviceRole = arg$.serviceRole, existingServices = arg$.existingServices;
  if (existingServices.includes(serviceRole)) {
    console.log(red("Service " + cyan(serviceRole) + " already exists in this application"));
    return process.exit(1);
  }
}
function getExistingServices(services){
  var existingServices, protectionLevel, that;
  existingServices = [];
  for (protectionLevel in services) {
    if (that = services[protectionLevel]) {
      existingServices.push(Object.keys(that));
    }
  }
  return flatten(existingServices);
}
function parseCommandLine(commandLineArgs){
  var data, questions, _, entityName, serviceRole, serviceType, author, templateName, modelName, description;
  data = {};
  questions = [];
  _ = commandLineArgs[0], _ = commandLineArgs[1], entityName = commandLineArgs[2], serviceRole = commandLineArgs[3], serviceType = commandLineArgs[4], author = commandLineArgs[5], templateName = commandLineArgs[6], modelName = commandLineArgs[7], description = commandLineArgs[8];
  if (serviceRole) {
    data.serviceRole = serviceRole;
  } else {
    questions.push({
      message: 'Role of the service to create:',
      type: 'input',
      name: 'serviceRole',
      filter: function(input){
        return input.trim();
      },
      validate: function(input){
        return input.length > 0;
      }
    });
  }
  if (serviceType) {
    data.serviceType = serviceType;
  } else {
    questions.push({
      message: 'Type of the service to create:',
      type: 'input',
      name: 'serviceType',
      filter: function(input){
        return input.trim();
      },
      validate: function(input){
        return input.length > 0;
      }
    });
  }
  if (description) {
    data.description = description;
  } else {
    questions.push({
      message: 'Description:',
      type: 'input',
      name: 'description',
      filter: function(input){
        return input.trim();
      }
    });
  }
  if (author) {
    data.author = author;
  } else {
    questions.push({
      message: 'Author:',
      type: 'input',
      name: 'author',
      filter: function(input){
        return input.trim();
      },
      validator: function(input){
        return input.length > 0;
      }
    });
  }
  if (templateName) {
    data.templateName = templateName;
  } else {
    questions.push({
      message: 'Template:',
      type: 'list',
      name: 'templateName',
      choices: serviceRoles()
    });
  }
  if (modelName) {
    data.modelName = modelName;
  } else {
    questions.push({
      message: 'Name of the data model:',
      type: 'input',
      name: 'modelName',
      filter: function(input){
        return input.trim();
      }
    });
  }
  return {
    data: data,
    questions: questions
  };
}